@@ -1,9 +1,10 @@
+import typing
+
 from .url_methods import (
-    __return_json,
+    __return_json_v3,
     __validate_statistics_type,
     __validate_technical_indicators_time_delta,
 )
-import typing
 
 
 def technical_indicators(
@@ -12,7 +13,7 @@ def technical_indicators(
     period: int = 10,
     statistics_type: str = "SMA",
     time_delta: str = "daily",
-) -> typing.List[typing.Dict]:
+) -> typing.Optional[typing.List[typing.Dict]]:
     """
     Query FMP /technical_indicator/ API.
 
@@ -29,4 +30,4 @@ def technical_indicators(
         "period": period,
         "type": __validate_statistics_type(statistics_type),
     }
-    return __return_json(path=path, query_vars=query_vars)
+    return __return_json_v3(path=path, query_vars=query_vars)
